@@ -1,8 +1,10 @@
 context("test-bighero6")
 
 ## Big Hero 6
-test_that("bigHero6_pal raises warning with large number, x > 12", {
+test_that("bigHero6_pal raises warning with large number, x > 8", {
   expect_warning(bigHero6_pal()(9))
+  expect_warning(bigHero6_pal(reverse = TRUE)(9))
+  expect_error(bigHero6_pal(n = 9))
 })
 
 test_that("scale_colour_bigHero6 equals scale_color_bigHero6", {
